@@ -1,6 +1,6 @@
 package Devel::FindPerl;
 {
-  $Devel::FindPerl::VERSION = '0.010';
+  $Devel::FindPerl::VERSION = '0.011';
 }
 use strict;
 use warnings;
@@ -114,7 +114,7 @@ sub perl_is_same {
 
 	push @cmd, qw(-MConfig=myconfig -e print -e myconfig);
 
-	local $ENV{PATH} = join $Config{path_sep}, qw{/usr/bin /bin};
+	local @ENV{qw/PATH IFS CDPATH ENV BASH_ENV/} = ('') x 5;
 	my $pid = open2(my($in, $out), @cmd);
 	binmode $in, ':crlf' if $^O eq 'MSWin32';
 	my $ret = do { local $/; <$in> };
@@ -143,7 +143,7 @@ Devel::FindPerl - Find the path to your perl
 
 =head1 VERSION
 
-version 0.010
+version 0.011
 
 =head1 SYNOPSIS
 
